@@ -1,8 +1,7 @@
 import argparse
-import sys
 from pathlib import Path
 
-from tabsvsspaces.argparse.pathtype import PathType
+from tabsvsspaces.pathtype import PathType
 from tabsvsspaces.find_stats import find_stats
 from tabsvsspaces.print_stats import print_stats
 from tabsvsspaces.stats import Statistics
